@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
     no strict;
-    $VERSION = '0.11';
+    $VERSION = '0.12';
     @ISA = qw(DynaLoader);
     if ($ENV{MOD_PERL}) {
 	__PACKAGE__->bootstrap($VERSION);
@@ -295,6 +295,12 @@ Returns the time taken to process the request in microseconds:
 
  my $req_time = $server->req_time;
 
+=item vhost
+
+Returns the vhost entry
+
+ my $vhost = $server->vhost;
+
 =back
 
 =head1 SEE ALSO
